==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/RecurrenceScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.RecurrenceScheduleArgs.builder
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.WeekDay
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property hours [Required] List of hours for the schedule.
 * @property minutes [Required] List of minutes for the schedule.
 * @property monthDays List of month days for the schedule
 * @property weekDays List of days for the schedule.
 */
public data class RecurrenceScheduleArgs(
    public val hours: Output<List<Int>>,
    public val minutes: Output<List<Int>>,
    public val monthDays: Output<List<Int>>? = null,
    public val weekDays: Output<List<Either<String, WeekDay>>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.RecurrenceScheduleArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.RecurrenceScheduleArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.RecurrenceScheduleArgs.builder()
            .hours(hours.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .minutes(minutes.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .monthDays(monthDays?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .weekDays(
                weekDays?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform(
                            { args0 -> args0 },
                            { args0 -> args0.let({ args0 -> args0.toJava() }) },
                        )
                    })
                }),
            ).build()
}

/**
 * Builder for [RecurrenceScheduleArgs].
 */
@PulumiTagMarker
public class RecurrenceScheduleArgsBuilder internal constructor() {
    private var hours: Output<List<Int>>? = null

    private var minutes: Output<List<Int>>? = null

    private var monthDays: Output<List<Int>>? = null

    private var weekDays: Output<List<Either<String, WeekDay>>>? = null

    /**
     * @param value [Required] List of hours for the schedule.
     */
    @JvmName("uvgvuwwswsbnblut")
    public suspend fun hours(`value`: Output<List<Int>>) {
        this.hours = value
    }

    @JvmName("odomayyayjsemeud")
    public suspend fun hours(vararg values: Output<Int>) {
        this.hours = Output.all(values.asList())
    }

    /**
     * @param values [Required] List of hours for the schedule.
     */
    @JvmName("xwniscemfvceobkf")
    public suspend fun hours(values: List<Output<Int>>) {
        this.hours = Output.all(values)
    }

    /**
     * @param value [Required] List of minutes for the schedule.
     */
    @JvmName("sweetixvmwbldtsn")
    public suspend fun minutes(`value`: Output<List<Int>>) {
        this.minutes = value
    }

    @JvmName("gjchkhgpwambytnp")
    public suspend fun minutes(vararg values: Output<Int>) {
        this.minutes = Output.all(values.asList())
    }

    /**
     * @param values [Required] List of minutes for the schedule.
     */
    @JvmName("exdqqhtdefikriph")
    public suspend fun minutes(values: List<Output<Int>>) {
        this.minutes = Output.all(values)
    }

    /**
     * @param value List of month days for the schedule
     */
    @JvmName("ohjlyjbfffeqvodh")
    public suspend fun monthDays(`value`: Output<List<Int>>) {
        this.monthDays = value
    }

    @JvmName("lwudwftlanuhwmff")
    public suspend fun monthDays(vararg values: Output<Int>) {
        this.monthDays = Output.all(values.asList())
    }

    /**
     * @param values List of month days for the schedule
     */
    @JvmName("nojtfejsvulkxfhr")
    public suspend fun monthDays(values: List<Output<Int>>) {
        this.monthDays = Output.all(values)
    }

    /**
     * @param value List of days for the schedule.
     */
    @JvmName("bgldevdxijostcgl")
    public suspend fun weekDays(`value`: Output<List<Either<String, WeekDay>>>) {
        this.weekDays = value
    }

    @JvmName("vldnqldbagejhodt")
    public suspend fun weekDays(vararg values: Output<Either<String, WeekDay>>) {
        this.weekDays = Output.all(values.asList())
    }

    /**
     * @param values List of days for the schedule.
     */
    @JvmName("gdypgfqcsvdtseuq")
    public suspend fun weekDays(values: List<Output<Either<String, WeekDay>>>) {
        this.weekDays = Output.all(values)
    }

    /**
     * @param value [Required] List of hours for the schedule.
     */
    @JvmName("mqfpsekvjwrniycj")
    public suspend fun hours(`value`: List<Int>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hours = mapped
    }

    /**
     * @param values [Required] List of hours for the schedule.
     */
    @JvmName("ivflxpyrtvjoetar")
    public suspend fun hours(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hours = mapped
    }

    /**
     * @param value [Required] List of minutes for the schedule.
     */
    @JvmName("tkyrmcuhnlwgcbck")
    public suspend fun minutes(`value`: List<Int>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    /**
     * @param values [Required] List of minutes for the schedule.
     */
    @JvmName("eovnyikevdxgvuwf")
    public suspend fun minutes(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    /**
     * @param value List of month days for the schedule
     */
    @JvmName("aeceetemjdeosxfo")
    public suspend fun monthDays(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthDays = mapped
    }

    /**
     * @param values List of month days for the schedule
     */
    @JvmName("gqhuybenjiilcgtb")
    public suspend fun monthDays(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.monthDays = mapped
    }

    /**
     * @param value List of days for the schedule.
     */
    @JvmName("gyphuciymtmrktaj")
    public suspend fun weekDays(`value`: List<Either<String, WeekDay>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.weekDays = mapped
    }

    /**
     * @param values List of days for the schedule.
     */
    @JvmName("mgqytsjoaylqqcto")
    public suspend fun weekDays(vararg values: Either<String, WeekDay>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.weekDays = mapped
    }

    internal fun build(): RecurrenceScheduleArgs = RecurrenceScheduleArgs(
        hours = hours ?: throw PulumiNullFieldException("hours"),
        minutes = minutes ?: throw PulumiNullFieldException("minutes"),
        monthDays = monthDays,
        weekDays = weekDays,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/RecurrenceScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.RecurrenceScheduleArgs.builder
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.WeekDay
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property hours [Required] List of hours for the schedule.
 * @property minutes [Required] List of minutes for the schedule.
 * @property monthDays List of month days for the schedule
 * @property weekDays List of days for the schedule.
 */
public data class RecurrenceScheduleArgs(
    public val hours: Output<List<Int>>,
    public val minutes: Output<List<Int>>,
    public val monthDays: Output<List<Int>>? = null,
    public val weekDays: Output<List<Either<String, WeekDay>>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.RecurrenceScheduleArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.RecurrenceScheduleArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.RecurrenceScheduleArgs.builder()
            .hours(hours.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .minutes(minutes.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .monthDays(monthDays?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .weekDays(
                weekDays?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform(
                            { args0 -> args0 },
                            { args0 -> args0.let({ args0 -> args0.toJava() }) },
                        )
                    })
                }),
            ).build()
}

/**
 * Builder for [RecurrenceScheduleArgs].
 */
@PulumiTagMarker
public class RecurrenceScheduleArgsBuilder internal constructor() {
    private var hours: Output<List<Int>>? = null

    private var minutes: Output<List<Int>>? = null

    private var monthDays: Output<List<Int>>? = null

    private var weekDays: Output<List<Either<String, WeekDay>>>? = null

    /**
     * @param value [Required] List of hours for the schedule.
     */
    @JvmName("klloahqmloscwvlf")
    public suspend fun hours(`value`: Output<List<Int>>) {
        this.hours = value
    }

    @JvmName("sjeiyuxyreipttlj")
    public suspend fun hours(vararg values: Output<Int>) {
        this.hours = Output.all(values.asList())
    }

    /**
     * @param values [Required] List of hours for the schedule.
     */
    @JvmName("hkfltkucfryowutk")
    public suspend fun hours(values: List<Output<Int>>) {
        this.hours = Output.all(values)
    }

    /**
     * @param value [Required] List of minutes for the schedule.
     */
    @JvmName("qliyflifuxuboqxn")
    public suspend fun minutes(`value`: Output<List<Int>>) {
        this.minutes = value
    }

    @JvmName("reqegiabmdyikwbt")
    public suspend fun minutes(vararg values: Output<Int>) {
        this.minutes = Output.all(values.asList())
    }

    /**
     * @param values [Required] List of minutes for the schedule.
     */
    @JvmName("gbpgvnyfxxgmhclt")
    public suspend fun minutes(values: List<Output<Int>>) {
        this.minutes = Output.all(values)
    }

    /**
     * @param value List of month days for the schedule
     */
    @JvmName("wqmwrijmtevwarem")
    public suspend fun monthDays(`value`: Output<List<Int>>) {
        this.monthDays = value
    }

    @JvmName("ryyehelntbbxnjow")
    public suspend fun monthDays(vararg values: Output<Int>) {
        this.monthDays = Output.all(values.asList())
    }

    /**
     * @param values List of month days for the schedule
     */
    @JvmName("nbfxubutmacmndnt")
    public suspend fun monthDays(values: List<Output<Int>>) {
        this.monthDays = Output.all(values)
    }

    /**
     * @param value List of days for the schedule.
     */
    @JvmName("wffwcxvfytpwgepp")
    public suspend fun weekDays(`value`: Output<List<Either<String, WeekDay>>>) {
        this.weekDays = value
    }

    @JvmName("pwnvxsqgngwaqhpr")
    public suspend fun weekDays(vararg values: Output<Either<String, WeekDay>>) {
        this.weekDays = Output.all(values.asList())
    }

    /**
     * @param values List of days for the schedule.
     */
    @JvmName("axwiypfefbdqkdtk")
    public suspend fun weekDays(values: List<Output<Either<String, WeekDay>>>) {
        this.weekDays = Output.all(values)
    }

    /**
     * @param value [Required] List of hours for the schedule.
     */
    @JvmName("xxgqfaqwpjboelea")
    public suspend fun hours(`value`: List<Int>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hours = mapped
    }

    /**
     * @param values [Required] List of hours for the schedule.
     */
    @JvmName("vqhjsdlwqbxovcdw")
    public suspend fun hours(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hours = mapped
    }

    /**
     * @param value [Required] List of minutes for the schedule.
     */
    @JvmName("cipxphecfvmaaetg")
    public suspend fun minutes(`value`: List<Int>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    /**
     * @param values [Required] List of minutes for the schedule.
     */
    @JvmName("nrbegqhrgogpwgmr")
    public suspend fun minutes(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    /**
     * @param value List of month days for the schedule
     */
    @JvmName("xiesxxwxkaioybrs")
    public suspend fun monthDays(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthDays = mapped
    }

    /**
     * @param values List of month days for the schedule
     */
    @JvmName("tkhdfxkmsdttffxa")
    public suspend fun monthDays(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.monthDays = mapped
    }

    /**
     * @param value List of days for the schedule.
     */
    @JvmName("yayclwgidspwucxt")
    public suspend fun weekDays(`value`: List<Either<String, WeekDay>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.weekDays = mapped
    }

    /**
     * @param values List of days for the schedule.
     */
    @JvmName("ogtrqjkffbqfvmku")
    public suspend fun weekDays(vararg values: Either<String, WeekDay>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.weekDays = mapped
    }

    internal fun build(): RecurrenceScheduleArgs = RecurrenceScheduleArgs(
        hours = hours ?: throw PulumiNullFieldException("hours"),
        minutes = minutes ?: throw PulumiNullFieldException("minutes"),
        monthDays = monthDays,
        weekDays = weekDays,
    )
}
